@@ -8,7 +8,7 @@ import secrets
 app = Flask(__name__)
 app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
 app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:////tmp/ttsi.db'
-secret_key = os.environ['SECRET_KEY']
+secret_key = os.environ.get('SECRET_KEY')
 
 if not secret_key:
     tmp_file = "/tmp/ttsi_secret.txt"
